summaryrefslogtreecommitdiffstats
path: root/languages/cpp/debugger
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 12:00:33 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 12:00:33 -0600
commit7e66d7c3611d907ea28b140281b472bb1c406be6 (patch)
treed0512bf457c2bfe012f455b42ab78651afb81438 /languages/cpp/debugger
parentc3b301575a98e4c3505ad95534d6192b65539dab (diff)
downloadtdevelop-7e66d7c3611d907ea28b140281b472bb1c406be6.tar.gz
tdevelop-7e66d7c3611d907ea28b140281b472bb1c406be6.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'languages/cpp/debugger')
-rw-r--r--languages/cpp/debugger/breakpoint.cpp10
-rw-r--r--languages/cpp/debugger/dbgpsdlg.cpp2
-rw-r--r--languages/cpp/debugger/dbgtoolbar.cpp4
-rw-r--r--languages/cpp/debugger/debuggerpart.cpp10
-rw-r--r--languages/cpp/debugger/framestackwidget.cpp16
-rw-r--r--languages/cpp/debugger/gdbbreakpointwidget.cpp8
-rw-r--r--languages/cpp/debugger/gdbcommand.cpp2
-rw-r--r--languages/cpp/debugger/gdbcontroller.cpp32
-rw-r--r--languages/cpp/debugger/memviewdlg.cpp14
-rw-r--r--languages/cpp/debugger/variablewidget.cpp92
-rw-r--r--languages/cpp/debugger/variablewidget.h20
11 files changed, 105 insertions, 105 deletions
diff --git a/languages/cpp/debugger/breakpoint.cpp b/languages/cpp/debugger/breakpoint.cpp
index c42f32c9..1b6efdaf 100644
--- a/languages/cpp/debugger/breakpoint.cpp
+++ b/languages/cpp/debugger/breakpoint.cpp
@@ -213,7 +213,7 @@ bool Breakpoint::match(const Breakpoint* breakpoint) const
TQString Breakpoint::dbgRemoveCommand() const
{
if (dbgId_>0)
- return TQString("-break-delete %1").tqarg(dbgId_); // gdb command - not translatable
+ return TQString("-break-delete %1").arg(dbgId_); // gdb command - not translatable
return TQString();
}
@@ -386,7 +386,7 @@ FilePosBreakpoint::FilePosBreakpoint(const TQString &fileName, int lineNum,
: Breakpoint(temporary, enabled)
{
// Sets 'subtype'
- setLocation(TQString("%1:%2").tqarg(fileName).tqarg(lineNum));
+ setLocation(TQString("%1:%2").arg(fileName).arg(lineNum));
}
FilePosBreakpoint::~FilePosBreakpoint()
@@ -482,7 +482,7 @@ void FilePosBreakpoint::setLocation(const TQString& location)
line_ = regExp1.cap(2).toInt();
- location_ = TQString("%1:%2").tqarg(fileName_).tqarg(regExp1.cap(2));
+ location_ = TQString("%1:%2").arg(fileName_).arg(regExp1.cap(2));
}
else
{
@@ -536,7 +536,7 @@ void Watchpoint::setBreakpoint(GDBController* controller)
controller->addCommandBeforeRun(
new GDBCommand(
- TQString("-data-evaluate-expression &%1").tqarg(varName_),
+ TQString("-data-evaluate-expression &%1").arg(varName_),
this,
&Watchpoint::handleAddressComputed));
}
@@ -547,7 +547,7 @@ void Watchpoint::handleAddressComputed(const GDBMI::ResultRecord& r)
address_ = r["value"].literal().toULongLong(0, 16);
controller()->addCommandBeforeRun(
new GDBCommand(
- TQString("-break-watch *%1").tqarg(r["value"].literal()),
+ TQString("-break-watch *%1").arg(r["value"].literal()),
static_cast<Breakpoint*>(this),
&Watchpoint::handleSet));
}
diff --git a/languages/cpp/debugger/dbgpsdlg.cpp b/languages/cpp/debugger/dbgpsdlg.cpp
index c31f4a4c..a399b5e1 100644
--- a/languages/cpp/debugger/dbgpsdlg.cpp
+++ b/languages/cpp/debugger/dbgpsdlg.cpp
@@ -172,7 +172,7 @@ void Dbg_PS_Dialog::slotProcessExited()
// to 'arg'.
i18n("<b>Could not parse output from the <tt>ps</tt> command.</b>"
"<p>The following line could not be parsed:"
- "<b><tt>%1</tt>").tqarg(item),
+ "<b><tt>%1</tt>").arg(item),
i18n("Internal error"), "gdb_error" );
break;
}
diff --git a/languages/cpp/debugger/dbgtoolbar.cpp b/languages/cpp/debugger/dbgtoolbar.cpp
index 27b79783..0ee45b63 100644
--- a/languages/cpp/debugger/dbgtoolbar.cpp
+++ b/languages/cpp/debugger/dbgtoolbar.cpp
@@ -121,7 +121,7 @@ void DbgMoveHandle::mousePressEvent(TQMouseEvent *e)
setFrameStyle(TQFrame::Panel|TQFrame::Sunken);
TQApplication::setOverrideCursor(TQCursor(sizeAllCursor));
setPalette(TQPalette(colorGroup().background()));
- tqrepaint();
+ repaint();
}
}
@@ -135,7 +135,7 @@ void DbgMoveHandle::mouseReleaseEvent(TQMouseEvent *e)
setFrameStyle(TQFrame::Panel|TQFrame::Raised);
TQApplication::restoreOverrideCursor();
setPalette(TQPalette(colorGroup().background()));
- tqrepaint();
+ repaint();
}
// **************************************************************************
diff --git a/languages/cpp/debugger/debuggerpart.cpp b/languages/cpp/debugger/debuggerpart.cpp
index 8fff0206..fb1577d4 100644
--- a/languages/cpp/debugger/debuggerpart.cpp
+++ b/languages/cpp/debugger/debuggerpart.cpp
@@ -515,12 +515,12 @@ void DebuggerPart::contextMenu(TQPopupMenu *popup, const Context *context)
if (!m_contextIdent.isEmpty())
{
TQString squeezed = KStringHandler::csqueeze(m_contextIdent, 30);
- int id = popup->insertItem( i18n("Evaluate: %1").tqarg(squeezed),
+ int id = popup->insertItem( i18n("Evaluate: %1").arg(squeezed),
this, TQT_SLOT(contextEvaluate()),
0, -1, index);
index += running;
popup->setWhatsThis(id, i18n("<b>Evaluate expression</b><p>Shows the value of the expression under the cursor."));
- int id2 = popup->insertItem( i18n("Watch: %1").tqarg(squeezed),
+ int id2 = popup->insertItem( i18n("Watch: %1").arg(squeezed),
this, TQT_SLOT(contextWatch()),
0, -1, index);
index += running;
@@ -659,7 +659,7 @@ bool DebuggerPart::startDebugger()
{
KMessageBox::information(
mainWindow()->main(),
- i18n("Could not locate the debugging shell '%1'.").tqarg( shell_without_args ),
+ i18n("Could not locate the debugging shell '%1'.").arg( shell_without_args ),
i18n("Debugging Shell Not Found"), "gdb_error" );
return false;
}
@@ -955,7 +955,7 @@ void DebuggerPart::slotExamineCore()
if (coreFile.isNull())
return;
- mainWindow()->statusBar()->message(i18n("Examining core file %1").tqarg(coreFile), 1000);
+ mainWindow()->statusBar()->message(i18n("Examining core file %1").arg(coreFile), 1000);
startDebugger();
controller->slotCoreFile(coreFile);
@@ -976,7 +976,7 @@ void DebuggerPart::slotAttachProcess()
bool DebuggerPart::attachProcess(int pid)
{
- mainWindow()->statusBar()->message(i18n("Attaching to process %1").tqarg(pid), 1000);
+ mainWindow()->statusBar()->message(i18n("Attaching to process %1").arg(pid), 1000);
bool ret = startDebugger();
controller->slotAttachTo(pid);
diff --git a/languages/cpp/debugger/framestackwidget.cpp b/languages/cpp/debugger/framestackwidget.cpp
index 2b8ae5a6..d7f50778 100644
--- a/languages/cpp/debugger/framestackwidget.cpp
+++ b/languages/cpp/debugger/framestackwidget.cpp
@@ -111,7 +111,7 @@ void FramestackWidget::slotSelectionChanged(TQListViewItem *thisItem)
if (frame->threadNo() != -1)
controller_->addCommand(
new GDBCommand(TQString("-thread-select %1")
- .tqarg(frame->threadNo()).ascii()));
+ .arg(frame->threadNo()).ascii()));
viewedThread_ = findThread(frame->threadNo());
getBacktrace(frame->frameNo(), frame->frameNo() + frameChunk_);
@@ -208,7 +208,7 @@ void FramestackWidget::getBacktrace(int min_frame, int max_frame)
maxFrame_ = max_frame;
controller_->addCommand(
- new GDBCommand(TQString("-stack-info-depth %1").tqarg(max_frame+1),
+ new GDBCommand(TQString("-stack-info-depth %1").arg(max_frame+1),
this,
&FramestackWidget::handleStackDepth));
}
@@ -224,7 +224,7 @@ void FramestackWidget::handleStackDepth(const GDBMI::ResultRecord& r)
//add the following command to the front, so noone switches threads in between
controller_->addCommandToFront(
new GDBCommand(TQString("-stack-list-frames %1 %2")
- .tqarg(minFrame_).tqarg(maxFrame_),
+ .arg(minFrame_).arg(maxFrame_),
this, &FramestackWidget::parseGDBBacktraceList));
}
@@ -236,7 +236,7 @@ void FramestackWidget::getBacktraceForThread(int threadNo)
// Switch to the target thread.
controller_->addCommand(
new GDBCommand(TQString("-thread-select %1")
- .tqarg(threadNo).ascii()));
+ .arg(threadNo).ascii()));
viewedThread_ = findThread(threadNo);
}
@@ -248,7 +248,7 @@ void FramestackWidget::getBacktraceForThread(int threadNo)
// Switch back to the original thread.
controller_->addCommand(
new GDBCommand(TQString("-thread-select %1")
- .tqarg(currentThread).ascii()));
+ .arg(currentThread).ascii()));
}
}
@@ -274,13 +274,13 @@ void FramestackWidget::handleThreadList(const GDBMI::ResultRecord& r)
TQString id = ids.results[i]->value->literal();
controller_->addCommand(
- new GDBCommand(TQString("-thread-select %1").tqarg(id).ascii(),
+ new GDBCommand(TQString("-thread-select %1").arg(id).ascii(),
this, &FramestackWidget::handleThread));
}
controller_->addCommand(
new GDBCommand(TQString("-thread-select %1")
- .tqarg(controller_->currentThread()).ascii()));
+ .arg(controller_->currentThread()).ascii()));
}
// Get backtrace for the current thread. We need to do this
@@ -558,7 +558,7 @@ ThreadStackItem::ThreadStackItem(FramestackWidget *parent, unsigned threadNo)
: TQListViewItem(parent),
threadNo_(threadNo)
{
- setText(0, i18n("Thread %1").tqarg(threadNo_));
+ setText(0, i18n("Thread %1").arg(threadNo_));
setExpandable(true);
}
diff --git a/languages/cpp/debugger/gdbbreakpointwidget.cpp b/languages/cpp/debugger/gdbbreakpointwidget.cpp
index 18851c58..b2f47d99 100644
--- a/languages/cpp/debugger/gdbbreakpointwidget.cpp
+++ b/languages/cpp/debugger/gdbbreakpointwidget.cpp
@@ -377,10 +377,10 @@ void GDBBreakpointWidget::slotWatchpointHit(int id,
"Address: 0x%2<br>"
"Old value: %3<br>"
"New value: %4")
- .tqarg(b->varName())
- .tqarg(b->address(), 0, 16)
- .tqarg(oldValue)
- .tqarg(newValue));
+ .arg(b->varName())
+ .arg(b->address(), 0, 16)
+ .arg(oldValue)
+ .arg(newValue));
}
/***************************************************************************/
diff --git a/languages/cpp/debugger/gdbcommand.cpp b/languages/cpp/debugger/gdbcommand.cpp
index c6c4bbc3..b5412dc0 100644
--- a/languages/cpp/debugger/gdbcommand.cpp
+++ b/languages/cpp/debugger/gdbcommand.cpp
@@ -105,7 +105,7 @@ ModifyBreakpointCommand::cmdToSend()
if (bp_->dbgId() > 0)
{
TQString s(initialString());
- s = s.tqarg(bp_->dbgId()) + "\n";
+ s = s.arg(bp_->dbgId()) + "\n";
return s.local8Bit();
}
else
diff --git a/languages/cpp/debugger/gdbcontroller.cpp b/languages/cpp/debugger/gdbcontroller.cpp
index 7808fccc..b0c3171e 100644
--- a/languages/cpp/debugger/gdbcontroller.cpp
+++ b/languages/cpp/debugger/gdbcontroller.cpp
@@ -294,7 +294,7 @@ void GDBController::queueCmd(GDBCommand *cmd, enum queue_where queue_where)
KMessageBox::information(
0,
i18n("<b>Gdb command sent when debugger is not running</b><br>"
- "The command was:<br> %1").tqarg(cmd->initialString()),
+ "The command was:<br> %1").arg(cmd->initialString()),
i18n("Internal error"), "gdb_error");
return;
}
@@ -500,7 +500,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
if (reason == "exited-signalled")
{
programNoApp(i18n("Exited on signal %1")
- .tqarg(r["signal-name"].literal()), false);
+ .arg(r["signal-name"].literal()), false);
// FIXME: figure out why this variable is needed.
programHasExited_ = true;
state_reload_needed = false;
@@ -554,7 +554,7 @@ void GDBController::actOnProgramPauseMI(const GDBMI::ResultRecord& r)
// that'll end the program.
KMessageBox::information(0,
i18n("Program received signal %1 (%2)")
- .tqarg(name).tqarg(user_name),
+ .arg(name).arg(user_name),
i18n("Received signal"));
}
}
@@ -716,9 +716,9 @@ void GDBController::handleMiFileListExecSourceFile(const GDBMI::ResultRecord& r)
"Command was: %1\n"
"Response is: %2\n"
"Invalid response kind: \"%3\"")
- .tqarg(currentCmd_->rawDbgCommand())
- .tqarg(buf)
- .tqarg(r.reason),
+ .arg(currentCmd_->rawDbgCommand())
+ .arg(buf)
+ .arg(r.reason),
i18n("Invalid gdb reply"), "gdb_error");
#endif
}
@@ -846,7 +846,7 @@ bool GDBController::start(const TQString& shell, const DomUtil::PairList& run_en
i18n("<b>Could not start debugger.</b>"
"<p>Could not run '%1'. "
"Make sure that the path name is specified correctly."
- ).tqarg(dbgProcess_->args()[0].data()),
+ ).arg(dbgProcess_->args()[0].data()),
i18n("Could not start debugger"), "gdb_error");
return false;
@@ -1159,7 +1159,7 @@ void GDBController::slotRun()
" %1\n"
"<br>does not exist. Check that you have specified "
"the right application in the debugger configuration."
- ).tqarg(app.fileName()),
+ ).arg(app.fileName()),
i18n("Application does not exist"));
// FIXME: after this, KDevelop will still show that debugger
@@ -1176,7 +1176,7 @@ void GDBController::slotRun()
"<p>The application does not have the executable bit set. "
"Try rebuilding the project, or change permissions "
"manually."
- ).tqarg(app.fileName()),
+ ).arg(app.fileName()),
i18n("Could not run application"));
slotStopDebugger();
}
@@ -1324,11 +1324,11 @@ void GDBController::selectFrame(int frameNo, int threadNo)
{
if (viewedThread_ != threadNo)
queueCmd(new GDBCommand(
- TQString("-thread-select %1").tqarg(threadNo).ascii()));
+ TQString("-thread-select %1").arg(threadNo).ascii()));
}
queueCmd(new GDBCommand(
- TQString("-stack-select-frame %1").tqarg(frameNo).ascii()));
+ TQString("-stack-select-frame %1").arg(frameNo).ascii()));
// Will emit the 'thread_or_frame_changed' event.
queueCmd(new GDBCommand("-stack-info-frame",
@@ -1590,7 +1590,7 @@ void GDBController::slotDbgStdout(KProcess *, char *buf, int buflen)
"<p>The debugger component encountered an internal error while "
"processing a reply from gdb. Please submit a bug report."),
i18n("The exception is: %1\n"
- "The MI response is: %2").tqarg(e.what()).tqarg(reply.data()),
+ "The MI response is: %2").arg(e.what()).arg(reply.data()),
i18n("Internal debugger error"));
destroyCurrentCommand();
@@ -1749,8 +1749,8 @@ void GDBController::explainDebuggerStatus()
"%2 commands being processed by gdb\n"
"Debugger state: %3\n");
information =
- information.tqarg(cmdList_.count()).tqarg(currentCmd_ ? 1 : 0)
- .tqarg(state_);
+ information.arg(cmdList_.count()).arg(currentCmd_ ? 1 : 0)
+ .arg(state_);
if (currentCmd_)
{
@@ -1758,8 +1758,8 @@ void GDBController::explainDebuggerStatus()
"Current command text: '%2'\n"
"Current command origianl text: '%3'\n");
- extra = extra.tqarg(
- typeid(*currentCmd_).name()).tqarg(currentCmd_->cmdToSend()).
+ extra = extra.arg(
+ typeid(*currentCmd_).name()).arg(currentCmd_->cmdToSend()).
arg(currentCmd_->initialString());
information += extra;
}
diff --git a/languages/cpp/debugger/memviewdlg.cpp b/languages/cpp/debugger/memviewdlg.cpp
index 3b69c206..4db5b0b8 100644
--- a/languages/cpp/debugger/memviewdlg.cpp
+++ b/languages/cpp/debugger/memviewdlg.cpp
@@ -263,8 +263,8 @@ namespace GDBDebugger
new
GDBCommand(
TQString("-data-read-memory %1 x 1 1 %2")
- .tqarg(rangeSelector_->startAddressLineEdit->text())
- .tqarg(size).ascii(),
+ .arg(rangeSelector_->startAddressLineEdit->text())
+ .arg(size).ascii(),
this,
&MemoryView::memoryRead));
}
@@ -280,7 +280,7 @@ namespace GDBDebugger
start_ = startAsString_.toUInt(0, 0);
setCaption(TQString("%1 (%2 bytes)")
- .tqarg(startAsString_).tqarg(amount_));
+ .arg(startAsString_).arg(amount_));
emit captionChanged(caption());
KHE::BytesEditInterface* bytesEditor
@@ -328,9 +328,9 @@ namespace GDBDebugger
controller_->addCommand(
new GDBCommand(
TQString("set *(char*)(%1 + %2) = %3")
- .tqarg(start_)
- .tqarg(i)
- .tqarg(TQString::number(data_[i]))));
+ .arg(start_)
+ .arg(i)
+ .arg(TQString::number(data_[i]))));
}
}
@@ -374,7 +374,7 @@ namespace GDBDebugger
new
GDBCommand(
TQString("-data-read-memory %1 x 1 1 %2")
- .tqarg(start_).tqarg(amount_).ascii(),
+ .arg(start_).arg(amount_).ascii(),
this,
&MemoryView::memoryRead));
}
diff --git a/languages/cpp/debugger/variablewidget.h b/languages/cpp/debugger/variablewidget.h
index cb8ffb0f..da885216 100644
--- a/languages/cpp/debugger/variablewidget.h
+++ b/languages/cpp/debugger/variablewidget.h
@@ -186,16 +186,16 @@ private:
/***************************************************************************/
/***************************************************************************/
-/** List view item that can 'trim' outdated tqchildren.
+/** List view item that can 'trim' outdated children.
- The instances of this class hold a number of tqchildren corresponding
+ The instances of this class hold a number of children corresponding
to variables. When program state changes, such as after a step in source,
some variable values can change, and some variables can go out of scope.
We need
- highlight modified variables
- remove gone variables
- We could just remove all tqchildren and repopulate the list from
+ We could just remove all children and repopulate the list from
the data from debugger, but then we'd loose information about previous
variable values.
@@ -286,7 +286,7 @@ public:
/** Recursively clears the varobjName_ field, making
*this completely disconnected from gdb.
- Automatically makes *this and tqchildren disables,
+ Automatically makes *this and children disables,
since there's no possible interaction with unhooked
object.
*/
@@ -300,7 +300,7 @@ public:
format_t formatFromGdbModifier(char c) const;
/** Clears highliting for this variable and
- all its tqchildren. */
+ all its children. */
void clearHighlight();
/** Sets new top-level textual value of this variable.
@@ -333,7 +333,7 @@ private:
- sets varobjName_ to 'name'
- sets format, if it's not default one
- gets initial value
- - if item is open, gets tqchildren.
+ - if item is open, gets children.
*/
void setVarobjName(const TQString& name);
@@ -348,12 +348,12 @@ private:
int column, int width, int align );
void varobjCreated(const GDBMI::ResultRecord& r);
void valueDone(const GDBMI::ResultRecord& r);
- void tqchildrenDone(const GDBMI::ResultRecord& r);
- void tqchildrenOfFakesDone(const GDBMI::ResultRecord& r);
+ void childrenDone(const GDBMI::ResultRecord& r);
+ void childrenOfFakesDone(const GDBMI::ResultRecord& r);
void handleCurrentAddress(const TQValueVector<TQString>& lines);
void handleType(const TQValueVector<TQString>& lines);
- void createChildren(const GDBMI::ResultRecord& r, bool tqchildren_of_fake);
+ void createChildren(const GDBMI::ResultRecord& r, bool children_of_fake);
/** Called to handle the output of the cli print command.
*/
@@ -391,7 +391,7 @@ private:
static int varobjIndex;
int numChildren_;
- bool tqchildrenFetched_;
+ bool childrenFetched_;
TQString currentAddress_;
TQString lastObtainedAddress_;
diff --git a/languages/cpp/debugger/variablewidget.cpp b/languages/cpp/debugger/variablewidget.cpp
index 653a4b33..bc598978 100644
--- a/languages/cpp/debugger/variablewidget.cpp
+++ b/languages/cpp/debugger/variablewidget.cpp
@@ -54,7 +54,7 @@
recieved after current frame in the debugger can possibly changes.
The widget has a list item for each frame/thread combination, with
- variables as tqchildren. However, at each moment only one item is shown.
+ variables as children. However, at each moment only one item is shown.
When handling the slotCurrentFrame, we check if variables for the
current frame are available. If yes, we simply show the corresponding item.
Otherwise, we fetch the new data from debugger.
@@ -338,7 +338,7 @@ void VariableTree::slotContextMenu(KListView *, TQListViewItem *item)
controller_->addCommand(
new GDBCommand(
TQString("-data-evaluate-expression &%1")
- .tqarg(var->gdbExpression()),
+ .arg(var->gdbExpression()),
this,
&VariableTree::handleAddressComputed,
true /*handles error*/));
@@ -505,8 +505,8 @@ void VariableTree::updateCurrentFrame()
controller_->addCommand(
new GDBCommand(TQString("-stack-list-arguments 0 %1 %2")
- .tqarg(controller_->currentFrame())
- .tqarg(controller_->currentFrame())
+ .arg(controller_->currentFrame())
+ .arg(controller_->currentFrame())
.ascii(),
this,
&VariableTree::argumentsReady));
@@ -882,8 +882,8 @@ void VarItem::handleCliPrint(const TQValueVector<TQString>& lines)
{
controller_->addCommand(
new GDBCommand(TQString("-var-create %1 * \"%2\"")
- .tqarg(varobjName_)
- .tqarg(r.cap(1)),
+ .arg(varobjName_)
+ .arg(r.cap(1)),
this,
&VarItem::varobjCreated,
// On initial create, errors get reported
@@ -1078,7 +1078,7 @@ VarItem::VarItem(TrimmableItem *parent,
oldSpecialRepresentationSet_(false),
format_(natural),
numChildren_(0),
- tqchildrenFetched_(false),
+ childrenFetched_(false),
updateUnconditionally_(false),
frozen_(frozen),
initialCreation_(true),
@@ -1123,7 +1123,7 @@ VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
oldSpecialRepresentationSet_(false),
format_(format),
numChildren_(0),
- tqchildrenFetched_(false),
+ childrenFetched_(false),
updateUnconditionally_(false),
frozen_(false),
initialCreation_(false),
@@ -1146,7 +1146,7 @@ VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
controller_ = varTree()->controller();
// Set type and tqchildren.
originalValueType_ = varobj["type"].literal();
numChildren_ = varobj["numchild"].literal().toInt();
setExpandable(numChildren_ != 0);
@@ -1159,7 +1159,7 @@ VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
void VarItem::createVarobj()
{
TQString old = varobjName_;
- varobjName_ = TQString("KDEV%1").tqarg(varobjIndex++);
+ varobjName_ = TQString("KDEV%1").arg(varobjIndex++);
emit varobjNameChange(old, varobjName_);
if (frozen_)
@@ -1169,7 +1169,7 @@ void VarItem::createVarobj()
// variable and we create variable object from that.
controller_->addCommand(
new CliCommand(
- TQString("print %1").tqarg(expression_),
+ TQString("print %1").arg(expression_),
this,
&VarItem::handleCliPrint));
}
@@ -1177,7 +1177,7 @@ void VarItem::createVarobj()
{
controller_->addCommand(
new CliCommand(
- TQString("print /x &%1").tqarg(expression_),
+ TQString("print /x &%1").arg(expression_),
this,
&VarItem::handleCurrentAddress,
true));
@@ -1186,8 +1186,8 @@ void VarItem::createVarobj()
// Need to quote expression, otherwise gdb won't like
// spaces inside it.
new GDBCommand(TQString("-var-create %1 * \"%2\"")
- .tqarg(varobjName_)
- .tqarg(expression_),
+ .arg(varobjName_)
+ .arg(expression_),
this,
&VarItem::varobjCreated,
initialCreation_ ? false : true));
@@ -1209,7 +1209,7 @@ void VarItem::varobjCreated(const GDBMI::ResultRecord& r)
originalValueType_ = r["type"].literal();
if (!oldType.isEmpty() && oldType != originalValueType_)
{
// Type changed, the tqchildren might be no longer valid,
// so delete them.
for(TQListViewItem* child = firstChild(); child; )
{
@@ -1239,7 +1239,7 @@ void VarItem::setVarobjName(const TQString& name)
{
controller_->addCommand(
new GDBCommand(TQString("-var-set-format \"%1\" %2")
- .tqarg(varobjName_).tqarg(varobjFormatName())));
+ .arg(varobjName_).arg(varobjFormatName())));
}
// Get the initial value.
@@ -1247,7 +1247,7 @@ void VarItem::setVarobjName(const TQString& name)
if (isOpen())
{
// This regets tqchildren list.
setOpen(true);
}
}
@@ -1333,18 +1333,18 @@ void VarItem::valueDone(const GDBMI::ResultRecord& r)
}
void VarItem::createChildren(const GDBMI::ResultRecord& r,
- bool tqchildren_of_fake)
+ bool children_of_fake)
{
- const GDBMI::Value& tqchildren = r["tqchildren"];
+ const GDBMI::Value& children = r["children"];
/* In order to figure out which variable objects correspond
to base class subobject, we first must detect if *this
is a structure type. We use present of 'public'/'private'/'protected'
fake child as an indicator. */
bool structureType = false;
- if (!tqchildren_of_fake && tqchildren.size() > 0)
+ if (!children_of_fake && children.size() > 0)
{
- TQString exp = tqchildren[0]["exp"].literal();
+ TQString exp = children[0]["exp"].literal();
bool ok = false;
exp.toInt(&ok);
if (!ok || exp[0] != '*')
@@ -1353,23 +1353,23 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
}
}
- for (unsigned i = 0; i < tqchildren.size(); ++i)
+ for (unsigned i = 0; i < children.size(); ++i)
{
- TQString exp = tqchildren[i]["exp"].literal();
+ TQString exp = children[i]["exp"].literal();
// For artificial accessibility nodes,
// fetch their tqchildren.
if (exp == "public" || exp == "protected" || exp == "private")
{
- TQString name = tqchildren[i]["name"].literal();
+ TQString name = children[i]["name"].literal();
controller_->addCommand(new GDBCommand(
- "-var-list-tqchildren \"" +
+ "-var-list-children \"" +
name + "\"",
this,
- &VarItem::tqchildrenOfFakesDone));
+ &VarItem::childrenOfFakesDone));
}
else
{
/* All tqchildren of structures that are not artifical
are base subobjects. */
bool baseObject = structureType;
@@ -1388,7 +1388,7 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
}
if (existing)
{
- existing->setVarobjName(tqchildren[i]["name"].literal());
+ existing->setVarobjName(children[i]["name"].literal());
}
else
{
@@ -1396,20 +1396,20 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
<< exp << " " << baseObject << "\n";
// Propagate format from parent.
VarItem* v = 0;
- v = new VarItem(this, tqchildren[i], format_, baseObject);
+ v = new VarItem(this, children[i], format_, baseObject);
}
}
}
}
-void VarItem::tqchildrenDone(const GDBMI::ResultRecord& r)
+void VarItem::childrenDone(const GDBMI::ResultRecord& r)
{
createChildren(r, false);
- tqchildrenFetched_ = true;
+ childrenFetched_ = true;
}
-void VarItem::tqchildrenOfFakesDone(const GDBMI::ResultRecord& r)
+void VarItem::childrenOfFakesDone(const GDBMI::ResultRecord& r)
{
createChildren(r, true);
}
@@ -1603,8 +1603,8 @@ void VarItem::updateValue()
void VarItem::setValue(const TQString& new_value)
{
controller_->addCommand(
- new GDBCommand(TQString("-var-assign \"%1\" %2").tqarg(varobjName_)
- .tqarg(new_value)));
+ new GDBCommand(TQString("-var-assign \"%1\" %2").arg(varobjName_)
+ .arg(new_value)));
// And immediately reload it from gdb,
// so that it's display format is the one gdb uses,
@@ -1661,14 +1661,14 @@ void VarItem::recreateLocallyMaybe()
{
controller_->addCommand(
new CliCommand(
- TQString("print /x &%1").tqarg(expression_),
+ TQString("print /x &%1").arg(expression_),
this,
&VarItem::handleCurrentAddress,
true));
controller_->addCommand(
new CliCommand(
- TQString("whatis %1").tqarg(expression_),
+ TQString("whatis %1").arg(expression_),
this,
&VarItem::handleType));
}
@@ -1688,12 +1688,12 @@ void VarItem::setOpen(bool open)
{
TQListViewItem::setOpen(open);
- if (open && !tqchildrenFetched_)
+ if (open && !childrenFetched_)
{
controller_->addCommand(new GDBCommand(
- "-var-list-tqchildren \"" + varobjName_ + "\"",
+ "-var-list-children \"" + varobjName_ + "\"",
this,
- &VarItem::tqchildrenDone));
+ &VarItem::childrenDone));
}
}
@@ -1712,7 +1712,7 @@ bool VarItem::handleSpecialTypes()
return false;
varTree->controller()->addCommand(
new ResultlessCommand(TQString("print $kdev_d=%1.d")
- .tqarg(gdbExpression()),
+ .arg(gdbExpression()),
true /* ignore error */));
if (varTree->controller()->qtVersion() >= 4)
@@ -1760,7 +1760,7 @@ void VarItem::setFormat(format_t f)
if (numChildren_)
{
// If variable has tqchildren, change format for tqchildren.
// - for structures, that's clearly right
// - for arrays, that's clearly right
// - for pointers, this can be confusing, but nobody ever wants to
@@ -1775,7 +1775,7 @@ void VarItem::setFormat(format_t f)
{
controller_->addCommand(
new GDBCommand(TQString("-var-set-format \"%1\" %2")
- .tqarg(varobjName_).tqarg(varobjFormatName())));
+ .arg(varobjName_).arg(varobjFormatName())));
updateValue();
}
@@ -1876,7 +1876,7 @@ VariableTree* VarItem::varTree() const
void VarItem::unhookFromGdb()
{
// Unhook tqchildren first, so that child varitems are deleted
// before parent. Strictly speaking, we can avoid calling
// -var-delete on child varitems, but that's a bit cheesy,
for(TQListViewItem* child = firstChild();
@@ -1886,7 +1886,7 @@ void VarItem::unhookFromGdb()
}
alive_ = false;
- tqchildrenFetched_ = false;
+ childrenFetched_ = false;
emit varobjNameChange(varobjName_, "");
@@ -1894,7 +1894,7 @@ void VarItem::unhookFromGdb()
{
controller_->addCommand(
new GDBCommand(
- TQString("-var-delete \"%1\"").tqarg(varobjName_)));
+ TQString("-var-delete \"%1\"").arg(varobjName_)));
}
varobjName_ = "";
@@ -1146,7 +1146,7 @@ VarItem::VarItem(TrimmableItem *parent, const GDBMI::Value& varobj,
controller_ = varTree()->controller();
- // Set type and tqchildren.
+ // Set type and children.
originalValueType_ = varobj["type"].literal();
numChildren_ = varobj["numchild"].literal().toInt();
@@ -1209,7 +1209,7 @@ void VarItem::varobjCreated(const GDBMI::ResultRecord& r)
if (!oldType.isEmpty() && oldType != originalValueType_)
{
- // Type changed, the tqchildren might be no longer valid,
+ // Type changed, the children might be no longer valid,
// so delete them.
for(TQListViewItem* child = firstChild(); child; )
@@ -1247,7 +1247,7 @@ void VarItem::setVarobjName(const TQString& name)
if (isOpen())
{
- // This regets tqchildren list.
+ // This regets children list.
setOpen(true);
}
@@ -1353,23 +1353,23 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
// For artificial accessibility nodes,
- // fetch their tqchildren.
+ // fetch their children.
if (exp == "public" || exp == "protected" || exp == "private")
{
@@ -1353,23 +1353,23 @@ void VarItem::createChildren(const GDBMI::ResultRecord& r,
else
{
- /* All tqchildren of structures that are not artifical
+ /* All children of structures that are not artifical
are base subobjects. */
bool baseObject = structureType;
@@ -1760,7 +1760,7 @@ void VarItem::setFormat(format_t f)
if (numChildren_)
{
- // If variable has tqchildren, change format for tqchildren.
+ // If variable has children, change format for children.
// - for structures, that's clearly right
// - for arrays, that's clearly right
@@ -1876,7 +1876,7 @@ VariableTree* VarItem::varTree() const
void VarItem::unhookFromGdb()
{
- // Unhook tqchildren first, so that child varitems are deleted
+ // Unhook children first, so that child varitems are deleted
// before parent. Strictly speaking, we can avoid calling
// -var-delete on child varitems, but that's a bit cheesy,